## Changelog

### [0.1.5] 2021-03-09
- Improve continuous integration with Github actions
- Add PyPI and conda deployment
- Add first unit and integration tests of ACV calculations
- NGLview for displaying ACVs in jupyter notebooks
- Updated docs with jupyter-books
- Add interactive notebooks with Binder

### [0.1.1] 2021-03-03
- Initial test release of FRETraj, a Python module to calculate 
accessible-contact volumes (ACV) and predict FRET efficiencies.